#! /usr/bin/env python

from openturns import *

TESTPREAMBLE()
RandomGenerator.SetSeed(0)

try:
    distribution = Rice(0.5, 1.5)
    size = 10000
    sample = distribution.getSample(size)
    factory = RiceFactory()
    estimatedDistribution = factory.build(sample)
    print "distribution=", repr(distribution)
    print "Estimated distribution=", repr(estimatedDistribution)
    estimatedDistribution = factory.build(
        distribution.getParametersCollection())
    print "Distribution from parameters=", estimatedDistribution
    estimatedDistribution = factory.build()
    print "Default distribution=", estimatedDistribution
    estimatedRice = factory.buildAsRice(sample)
    print "Rice          =", distribution
    print "Estimated rice=", estimatedRice
    estimatedRice = factory.buildAsRice(distribution.getParametersCollection())
    print "Rice from parameters=", estimatedRice
    estimatedRice = factory.buildAsRice()
    print "Default rice=", estimatedRice

except:
    import sys
    print "t_RiceFactory_std.py", sys.exc_type, sys.exc_value
